# ai.os プロジェクト固有情報

## プロジェクト概要
- **名前**: ai.os
- **パッケージ**: aios
- **タイプ**: ArchLinux-based OS
- **役割**: AI統合OS基盤

## 現在の実装状況

### OS基盤
- **ベース**: ArchLinux + archiso
- **配布形式**: Docker container (bootstrap tar.gz)
- **ビルドシステム**: GitHub Actions自動ビルド
- **レジストリ**: Docker Hub, GitHub Packages, git.syui.ai

### 搭載パッケージ
```bash
base base-devel linux vim git zsh rust openssh openssl jq go nodejs docker podman bc
```

### AI統合コンポーネント
- **ai.bot**: Rust製、`/bin/ai`でインストール済み
- **ai.gpt**: 統合予定（Python + fastapi_mcp）
- **Container設定**: Podman用AI registryプリセット

## 将来の発展方向

### Phase 1: AI基盤統合
- **ai.gpt搭載**: MCPサーバー自動起動
- **ai.shell**: Claude Code風terminal組み込み
- **Python環境**: fastapi_mcp基盤

### Phase 2: ゲーム融合OS
- **ai.verse統合**: UEメタバース基盤
- **ai.card**: iOS/Web UI統合
- **自動起動**: systemdでAIサービス管理

### Phase 3: 統合デバイス化
- **ai.game device**: 専用ハードウェア対応
- **分散SNS**: atproto完全統合
- **現実反映**: ゲーム↔現実データ同期

## 技術仕様

### ビルド設定
- **profiledef.sh**: bootstrap modeでtar.gz生成
- **Version管理**: 日付ベース自動更新（YYYY.MM.DD）
- **CI/CD**: GitHub Actions + multi-registry push

### 設定管理
- **os-release**: `/etc/os-release`準拠
- **Container**: Podman shortname alias対応
- **Network**: ai.conf registryプリセット

### 開発環境
- **言語**: Rust（ai.bot）, Python（ai.gpt統合予定）
- **Shell**: zsh
- **Container**: Docker + Podman両対応

## 使用方法

### Docker実行
```bash
docker run -it git.syui.ai/ai/os ai
docker run -it syui/aios ai
docker run -it ghcr.io/syui/aios ai
```

### Podman実行
```bash
podman pull aios  # shortname alias
```

### ローカルビルド
```bash
./scpt/gh-actions.zsh  # GitHub Actions workflow生成
./build.zsh           # ローカルビルド実行
```